# Astro SQL CLI

Empower analysts to build workflows to transform data using SQL.

Find out more in the [docs](https://docs.astronomer.io/astro/cli/sql-cli).

## Getting started

### Install

```bash
    pip install astro-sql-cli
```

### Try it out

```bash
    flow version
```


## Development

Setup your local environment:

```bash
    make setup
```

Try your own version of the SQL CLI locally:

```bash
    poetry run flow version
```

Run the tests:

```bash
    make test
```
